==========================
Tendril Costing Primitives
==========================

.. image:: https://img.shields.io/travis/chintal/tendril-costing.svg
        :target: https://travis-ci.org/chintal/tendril-costing

.. image:: https://img.shields.io/pypi/v/tendril-costing.svg
        :target: https://pypi.python.org/pypi/tendril-costing

* License: AGPLv3
* Documentation: http://tendril-costing.readthedocs.org


Tendril Costing Primitives
